from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from models import Settings

_('Settings')

class SettingsAdmin(admin.ModelAdmin):
    list_display = ('key', 'value',)

admin.site.register(Settings, SettingsAdmin)


from django import template

from ..models import Settings

register = template.Library()

@register.simple_tag
def get_config(key):
    try:
        config = Settings.objects.get(key=key)
        return config.value
    except Settings.DoesNotExist:
        return ''



from django.db import models
from django.utils.translation import ugettext_lazy as _

class Settings(models.Model):
    key = models.CharField(_('key'), max_length=255)
    value = models.TextField(_('value'))

    class Meta:
        db_table = 'settings'
        verbose_name = _('setting')
        verbose_name_plural = _('settings')

    def __unicode__(self):
        return self.key



#!/usr/bin/env python
from os.path import join, dirname
from setuptools import setup, find_packages

from settings import __version__

def long_description():
    try:
        return open(join(dirname(__file__), 'README.rst')).read()
    except IOError:
        return ''

setup(
    name='djlime-settings',
    author='Andrey Butenko',
    author_email='whitespysoftware@yandex.ru',
    url='https://github.com/whitespy/djlime-settings',
    description='The application settings.',
    long_description=long_description(),
    version = __version__,
    license='BSD',
    packages=find_packages(),
    include_package_data=True,
    platforms='any',
    classifiers=['Framework :: Django',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: BSD License']
)
